## 中信行业指数行情

接口：ci_daily

描述：获取中信行业指数日线行情

限量：单次最大4000条，可循环提取

积分：5000积分可调取，可通过指数代码和日期参数循环获取所有数据

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | N | 行业代码 |
| trade_date | str | N | 交易日期（YYYYMMDD格式，下同） |
| start_date | str | N | 开始日期 |
| end_date | str | N | 结束日期 |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | Y | 指数代码 |
| trade_date | str | Y | 交易日期 |
| open | float | Y | 开盘点位 |
| low | float | Y | 最低点位 |
| high | float | Y | 最高点位 |
| close | float | Y | 收盘点位 |
| pre_close | float | Y | 昨日收盘点位 |
| change | float | Y | 涨跌点位 |
| pct_change | float | Y | 涨跌幅 |
| vol | float | Y | 成交量（万股） |
| amount | float | Y | 成交额（万元） |

接口示例

```python
pro = ts.pro_api('your token')

df = pro.ci_daily(trade_date='20230705', fields='ts_code,trade_date,open,low,high,close')
```

数据示例

```python
ts_code   trade_date       open        low       high      close
0    CI005001.CI   20230705  2757.5662  2736.8198  2764.1863  2754.2617
```